using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.FxCop.Sdk.Introspection;
using Microsoft.Cci;
using Microsoft.FxCop.Sdk;

namespace CustomStaticCodeAnalysisRules
{
    public class MemberVariableNameRule : BaseIntrospectionRule
    {
        public MemberVariableNameRule()
            : base("MemberVariableNameRule", 
			"CustomStaticCodeAnalysisRules.Rules.xml", 
			typeof(MemberVariableNameRule).Assembly)
        {
            
        }

        public override ProblemCollection Check(Member memberField)
        {
            Field field = memberField as Field;

            if (field == null || 
				field.Name == null || 
				field.Name.Name == null)
            {
                return null;
            }

            bool foundProblem = false;

            if (field.IsVisibleOutsideAssembly == false)
            {
                if (field.Name.Name.StartsWith("m_") == false)
                {
                    foundProblem = true;
                }
                else if (field.Name.Name.Length>2)
                {
                    if (Char.IsUpper(field.Name.Name[2]) == true)
                    {
                        foundProblem = true;
                    }
                }

                if (foundProblem == true)
                {
                    Resolution resolution = 
						base.GetResolution(field.Name.Name);
                    Problem problem = 
						new Problem(resolution, field.Name.Name);
                    base.Problems.Add(problem);
                }
            }

            return base.Problems;
        }

        
    }
}
