using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.TeamFoundation.VersionControl.Client;

namespace TfsBeyondTheGui.SourceControlRules
{
	[Serializable]
	public class CustomRule : PolicyBase
	{
		private string m_excludedWord = String.Empty;

		public override string Description
		{
			get { return this.Type; }
		}

		public override string InstallationInstructions
		{
			get
			{
				return "Download the policy DLL and register it using the .reg file.";
			}
			set
			{
				base.InstallationInstructions = value;
			}
		}

		public override bool Edit(IPolicyEditArgs policyEditArgs)
		{
			// show the editor dialog

			using (CustomRuleEditor editor = new CustomRuleEditor())			
            {
				editor.ExcludedWord = m_excludedWord;

				if (editor.ShowDialog() == System.Windows.Forms.DialogResult.OK)
				{
					m_excludedWord = editor.ExcludedWord;
				}
            }

			return true;
		}

		public override PolicyFailure[] Evaluate()
		{
			List<PolicyFailure> failures = new List<PolicyFailure>();

			if (String.IsNullOrEmpty(m_excludedWord) == true)
			{
				return failures.ToArray();
			}
			else
			{
				foreach (PendingChange change in 
					this.PendingCheckin.PendingChanges.AllPendingChanges)
				{
					if (change.FileName.Contains(m_excludedWord) == true)
					{
						failures.Add(
							new PolicyFailure(
							"Filename contains a restricted word.", this));
					}
				}

				return failures.ToArray();
			}
			
		}

		public override string Type
		{
			get { return "Checks that the file name does not contain the restricted word."; }
		}

		public override string TypeDescription
		{
			get { return "A longer displayable name."; }
		}
	}
}
